import { Component, inject } from '@angular/core';
import { NZ_MODAL_DATA } from 'ng-zorro-antd/modal';
import { horizontalInOut } from '../../../common.animation';
import { KnowledgeService } from '../../../services/knowledge.service';
import { CommonNzModule } from './../../../common.nz.module';
import { RiskItemVisualComponent } from './../risk-item-visual/risk-item-visual.component';

export interface RiskItemPickerModalData {
  title: string;
  items: Knowledge.RiskItem[];
  types: Knowledge.RiskTypeDto[];
  categories: Knowledge.RiskCategoryDto[];
  checkItemIds: number[];
  onChange: (itemIds: number[]) => void;
  preSearched: boolean;
}

@Component({
  selector: 'risk-item-picker-modal',
  standalone: true,
  imports: [CommonNzModule, RiskItemVisualComponent],
  templateUrl: './modal.component.html',
  styleUrl: './modal.component.less',
  animations: [horizontalInOut],
})
export class RiskItemPickerModalComponent {
  readonly nzModalData: RiskItemPickerModalData = inject(NZ_MODAL_DATA);
  category?: number;
  type?: number;
  filteredCategories: Knowledge.RiskCategoryDto[] = [];
  filteredItems: Knowledge.RiskItem[] = [];
  selectedItems: Knowledge.RiskItem[] = [];
  searchText = '';
  constructor(private knowledge: KnowledgeService) {}

  ngOnInit() {
    if (this.nzModalData.checkItemIds.length > 0) {
      this.selectedItems = this.items.filter(p => this.nzModalData.checkItemIds.includes(p.id));
    }
    if (this.nzModalData.types.length > 0 && this.nzModalData.preSearched) {
      this.type = this.nzModalData.types[0].id;
      this.onTypeChange(this.type);
    } else {
      this.onTypeChange(undefined);
    }
  }
  onTypeChange(value: number | undefined) {
    this.type = value;
    this.category = undefined;
    const typeDto = this.types.find(p => p.id === value);
    if (!typeDto) {
      this.filteredCategories = [];
      this.setFilteredItems();
      return;
    }
    this.filteredCategories = typeDto.categories;
    this.setFilteredItems();
  }
  onCategoryChange(value: number) {
    this.category = value;
    this.setFilteredItems();
  }
  onClear() {
    this.selectedItems = [];
    this.nzModalData.onChange([]);
  }
  onItemChange(value: number, boolean = true) {
    const item = this.items.find(p => p.id === value);
    if (item) {
      if (boolean) {
        this.selectedItems.unshift(item);
      } else {
        this.selectedItems = this.selectedItems.filter(p => p.id !== value);
      }
      this.nzModalData.onChange(this.selectedItems.map(p => p.id));
    }
  }

  onRemove(itemId: number) {
    this.selectedItems = this.selectedItems.filter(p => p.id !== itemId);
    this.nzModalData.onChange(this.selectedItems.map(p => p.id));
  }
  get title() {
    return this.nzModalData.title || '选择风险条目';
  }
  get items() {
    return this.nzModalData.items;
  }
  setFilteredItems() {
    let result = this.items;
    if (this.type) {
      result = result.filter(p => p.type === this.type);
    }
    if (this.category) {
      result = result.filter(p => p.category === this.category);
    }
    if (this.searchText) {
      result = result.filter(p => p.title.includes(this.searchText));
    }
    this.filteredItems = result;
  }
  get types() {
    return this.nzModalData.types;
  }
  get categories() {
    return this.nzModalData.categories;
  }
  get currentCategory() {
    return this.categories.find(c => c.id === this.category);
  }
  // get categoryTypeIsStation() {
  //   return this.currentCategory?.name === '车站';
  // }
}
